/*
 *	@title	Command Line Interface functions, user interface
 *	@author	imperix SA (dev@imperix.ch)
 *	@file	cli_commands.c
 */

#include "DSP28x_Project.h"								// Headers for C28346
#include "Core/macros.h"								// Global defines and macros
#include "Driver/cli.h"									// Command line interface interpreter
#include "user.h"										// User-level routines
#include <string.h>
#include <stdlib.h>
#include <stdio.h>


/**
 * Prototype here each user function first!
 */
void SetIpv(unsigned int argc, char *argv[]);
void SetMPPT(unsigned int argc, char *argv[]);


/**
 * Global variables
 */
extern Uint16 enable_MPPT;								// Boolean to activate/deactivate the MPP-Tracking
extern float Ipv_ref;									// PV current setpoint


void LoadCLIUserFunctions(void)
{
	/* This function is called by the core at system startup.
	 * the user-defined functions have to be registered
	 * by the command line interpreter before they can be used.
	 *
	 * These functions will be mapped in the /user folder in
	 * the command line mode. Use 'cd user' in order to be in this
	 * folder before using these commands.
	 */
	fs_mkcmd_user("setipv", SetIpv);
	fs_mkcmd_user("setmppt", SetMPPT);
}


void SetIpv(unsigned int argc, char *argv[])
{
	if (*argv[1] == '?')
	{
		printf("\nSet the PV current value (Ipv).");
		printf("\nExample : setIpv 1.2");
		return;
	}
	Ipv_ref = atof(argv[1]);;
}


void SetMPPT(unsigned int argc, char *argv[])
{
	if (*argv[1] == '?')
	{
		printf("\nSet the MPPT state. (1 to activate and 0 to deactivate)");
		printf("\nExample : setMPPT 1");
	return;
	}
	enable_MPPT = atoi(argv[1]);;
}
